@@ -113,6 +113,7 @@ class Cube():
 
     def __train_wrapper(self, config):
         self.config['proc']['pre_train'](self.config)
+        self.config['data']['model'].train() # Set model to training
         self.config['proc']['train_loop'](self.config)
         self.config['proc']['post_train'](self.config)
         for metric in self.config['data']['train_metrics']:
@@ -135,7 +136,9 @@ class Cube():
 
     def __val_wrapper(self, config):
         self.config['proc']['pre_val'](self.config)
-        self.config['proc']['val_loop'](self.config)
+        with torch.no_grad(): 
+            self.config['data']['model'].eval() # Set model to eval
+            self.config['proc']['val_loop'](self.config)
         self.config['proc']['post_val'](self.config)
         for metric in self.config['data']['val_metrics']:
             result = metric.reduce_wrap(self.config)
